EXPORTS
	?NewL@CMdaAudioOutputStream@@SAPAV1@AAVMMdaAudioOutputStreamCallback@@PAVCMdaServer@@@Z @ 1 NONAME ; public: static class CMdaAudioOutputStream * __cdecl CMdaAudioOutputStream::NewL(class MMdaAudioOutputStreamCallback &,class CMdaServer *)
	?GetBalanceL@CMdaAudioOutputStream@@QBEHXZ @ 2 NONAME ; public: int __thiscall CMdaAudioOutputStream::GetBalanceL(void)const 
	?GetBytes@CMdaAudioOutputStream@@QAEHXZ @ 3 NONAME ; public: int __thiscall CMdaAudioOutputStream::GetBytes(void)
	?SetBalanceL@CMdaAudioOutputStream@@QAEXH@Z @ 4 NONAME ; public: void __thiscall CMdaAudioOutputStream::SetBalanceL(int)
	?DataType@CMdaAudioOutputStream@@QBE?AVTFourCC@@XZ @ 5 NONAME ; public: class TFourCC  __thiscall CMdaAudioOutputStream::DataType(void)const 
	?SetDataTypeL@CMdaAudioOutputStream@@QAEXVTFourCC@@@Z @ 6 NONAME ; public: void __thiscall CMdaAudioOutputStream::SetDataTypeL(class TFourCC)
	?NewL@CMdaAudioOutputStream@@SAPAV1@AAVMMdaAudioOutputStreamCallback@@HH@Z @ 7 NONAME ; class CMdaAudioOutputStream * CMdaAudioOutputStream::NewL(class MMdaAudioOutputStreamCallback &, int, int)
	?CancelRegisterAudioResourceNotification@CMdaAudioOutputStream@@QAEHVTUid@@@Z @ 8 NONAME ; int CMdaAudioOutputStream::CancelRegisterAudioResourceNotification(class TUid)
	?RegisterAudioResourceNotification@CMdaAudioOutputStream@@QAEHAAVMMMFAudioResourceNotificationCallback@@VTUid@@ABVTDesC8@@@Z @ 9 NONAME ; int CMdaAudioOutputStream::RegisterAudioResourceNotification(class MMMFAudioResourceNotificationCallback &, class TUid, class TDesC8 const &)
	?WillResumePlay@CMdaAudioOutputStream@@QAEHXZ @ 10 NONAME ; int CMdaAudioOutputStream::WillResumePlay(void)
	?CustomInterface@CMdaAudioOutputStream@@QAEPAXVTUid@@@Z @ 11 NONAME ; void * CMdaAudioOutputStream::CustomInterface(class TUid)
	?KeepOpenAtEnd@CMdaAudioOutputStream@@QAEHXZ @ 12 NONAME ; int CMdaAudioOutputStream::KeepOpenAtEnd(void)
	?RequestStop@CMdaAudioOutputStream@@QAEHXZ @ 13 NONAME ; int CMdaAudioOutputStream::RequestStop(void)
	?Pause@CMdaAudioOutputStream@@QAEHXZ @ 14 NONAME ; int CMdaAudioOutputStream::Pause(void)
	?Resume@CMdaAudioOutputStream@@QAEHXZ @ 15 NONAME ; int CMdaAudioOutputStream::Resume(void)

